@@ -94,9 +94,9 @@ main() {
         "<?xml version='1.0' encoding='UTF-8'?>\n<"
         << mapping.map("metadata") << ">\n";
 
-    long len;
+    int len;
     const char* lenstr = getenv("CONTENT_LENGTH");
-    if (lenstr == NULL || sscanf(lenstr,"%ld", &len) != 1 || len < 0) {
+    if (lenstr == NULL || sscanf(lenstr,"%id", &len) != 1 || len < 0) {
         cout << " <error>input too small</error>\n</"
             << mapping.map("metadata") << ">\n" << flush;
         return 0;
@@ -113,7 +113,7 @@ main() {
     StringInputStream stream(e, len);
 
     // read the first line
-    const char* d;
+    const char* d = NULL;
     const int32_t maxlength = 1024;
     int32_t nread = stream.read(d, maxlength, maxlength);
     stream.reset(0);
